% Pole Placement Design for Magnetic Suspension
clear all;

% =============================================
% Pole Placement Design for Magnetic Suspension
% =============================================
% Model Parameters
Km = 1E-4;
d = 0.04;
m = 0.1;
g = 10;
i0 = sqrt(m*g/Km)*d/2;
Ki = 2*Km*i0/(d/2)^2;
Kx = 2*Km*i0^2/(d/2)^3;
% trajectory computation
A = [1 0 0 0 0 0; 1 2 4 8 16 32; 0 1 0 0 0 0; 0 1 4 12 32 80; 0 0 1 0 0 0; 0 0 2 12 48 160];
b = [0; d/2; 0; 0; 0; 0];
v = inv(A)*b;

% ======================================
% Open loop simulation
% ======================================
% open loop
dist = 0;
K_feedback = 0;
% simulation
options = simset('Solver','ode23s');
sim('ECE441_Ex13_solution',[0,3],options);
figure(1);
hold on;
grid on;
plot(time,y);
legend('feedforward simulation')
xlabel('time [sec]')
ylabel('potition [m/s]')

% ======================================
% Closed loop simulation
% ======================================
% closed loop
dist = 0;
K_feedback = 1;
% simulation
options = simset('Solver','ode23s');
sim('ECE441_Ex13_solution',[0,3],options);
figure(2);
hold on;
grid on;
plot(time,y);
legend('feedfback simulation')
xlabel('time [sec]')
ylabel('potition [m/s]')


figure(3);
plot(time,u);
legend('feedback controller output u')
grid on;
xlabel('time [sec]')
ylabel('current [A]')


% ======================================
% Closed loop simulation with disturbance step
% ======================================
% closed loop
dist = 0.05;
K_feedback = 1;
sim('ECE441_Ex13_solution',[0,3],options);
figure(4);
plot(time,y,time,yd);
legend('output','desired output')
grid on;
xlabel('time [sec]')
ylabel('position [m/s]')

figure(5);
plot(time,u);
legend('feedvback controller output')
grid on;
xlabel('time [sec]')
ylabel('current [A]')
